@@ -6,11 +6,11 @@
 #from mstrio.api import projects
 #from mstrio.api import objects as api_obj
 #from mstrio.project_objects import report
-from mstr_classes import rep
-from mstr_classes import mstr_global
-from mstr_classes import get_conn
+from mstr_robotics.mstr_classes import rep
+from mstr_robotics.mstr_classes import mstr_global
+from mstr_robotics.mstr_classes import get_conn
 from datetime import datetime
-import helper
+from mstr_robotics import helper
 import pandas as pd
 
 
