@@ -12,8 +12,8 @@ from mstrio.object_management import folder
 import pandas as pd
 #import error_controller
 #from mstrio.utils.error_handlers import ErrorHandler
-from helper import str_func
-from logger import logger
+from mstr_robotics.helper import str_func
+from mstr_robotics import logger
 
 str_func=str_func
 log=logger
